window.Gleam.initSearch([{"doc":"nbeet","title":"nbeet","content":"&lt;div align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://github.com/zwubs/nbeet&quot;&gt;\n    &lt;img src=&quot;https://raw.githubusercontent.com/zwubs/nbeet/main/images/nbeet.png&quot; alt=&quot;nbeet logo&quot; width=&quot;128&quot; height=&quot;128&quot;&gt;\n  &lt;/a&gt;\n\n  &lt;h1 align=&quot;center&quot; style=&quot;margin-bottom: 0; margin-top: 1rem;&quot;&gt;nbeet&lt;/h1&gt;\n\n  &lt;p align=&quot;center&quot;&gt;An NBT encoder and decoder for gleam&lt;/p&gt;\n\n[![Package Version](https://img.shields.io/hexpm/v/nbeet)](https://hex.pm/packages/nbeet)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nbeet/)\n\n&lt;/div&gt;\n\n## About\n`nbeet` is a gleam package for all your NBT needs. For those that don&#39;t know NBT (Named Binary Tag) is a file format utilized by the game Minecraft for storing information. This package focuses on encoding and decoding NBT data and has syntax inspired by [`gleam_json`](https://github.com/gleam-lang/json) and [`bison`](https://github.com/massivefermion/bison) packages.\n\n## Installation\nAdd `nbeet` to your Gleam project.\n\n```sh\ngleam add nbeet\n```\n\n## Usage\n### Encoding\n```gleam\nimport nbeet.{byte, compound, nbt, string}\n\npub fn encode_truth() -&gt; Result(BitArray, Nil) {\n  let nbt =\n    nbt(\n      &quot;in beet we&quot;,\n      compound([#(&quot;trust&quot;, byte(1)), #(&quot;must&quot;, string(&quot;true&quot;)), ])\n    )\n  nbeet.encode(nbt)\n}\n```\n\n### Decoding\n```gleam\nimport decode/zero\nimport gleam/result\nimport nbeet\n\npub type InBeetWe {\n  InBeetWe(trust: Int, must: String)\n}\n\nfn truth_decoder() {\n  use trust &lt;- zero.field(&quot;trust&quot;, zero.int)\n  use must &lt;- zero.field(&quot;must&quot;, zero.string)\n  zero.success(InBeetWe(trust, must))\n}\n\nfn decode_truth(nbt: BitArray) -&gt; Result(InBeetWe, Nil) {\n  let decoder = truth_decoder()\n  use #(_, in_beet_we) &lt;- result.try(nbeet.java_decode(nbt, decoder))\n  Ok(in_beet_we)\n}\n```\n","url":"index.html"},{"doc":"nbeet","title":"Nbt","content":"pub opaque type Nbt\n\n\nSynonyms:\nnbeet.Nbt\nnbeet Nbt","url":"nbeet.html#Nbt"},{"doc":"nbeet","title":"byte","content":"pub fn byte(byte: Int) -&gt; Tag\n\nSynonyms:\nnbeet.byte\nnbeet byte","url":"nbeet.html#byte"},{"doc":"nbeet","title":"byte_array","content":"pub fn byte_array(byte_array: BitArray) -&gt; Tag\n\nSynonyms:\nnbeet.byte_array\nnbeet byte_array","url":"nbeet.html#byte_array"},{"doc":"nbeet","title":"compound","content":"pub fn compound(compound: List(#(String, Tag))) -&gt; Tag\n\nSynonyms:\nnbeet.compound\nnbeet compound","url":"nbeet.html#compound"},{"doc":"nbeet","title":"double","content":"pub fn double(double: Float) -&gt; Tag\n\nSynonyms:\nnbeet.double\nnbeet double","url":"nbeet.html#double"},{"doc":"nbeet","title":"float","content":"pub fn float(float: Float) -&gt; Tag\n\nSynonyms:\nnbeet.float\nnbeet float","url":"nbeet.html#float"},{"doc":"nbeet","title":"int","content":"pub fn int(int: Int) -&gt; Tag\n\nSynonyms:\nnbeet.int\nnbeet int","url":"nbeet.html#int"},{"doc":"nbeet","title":"int_array","content":"pub fn int_array(int_array: List(Int)) -&gt; Tag\n\nSynonyms:\nnbeet.int_array\nnbeet int_array","url":"nbeet.html#int_array"},{"doc":"nbeet","title":"java_decode","content":"pub fn java_decode(\n  bit_array: BitArray,\n  decoder: Decoder(a),\n) -&gt; Result(#(String, a), List(DecodeError))\n\nSynonyms:\nnbeet.java_decode\nnbeet java_decode","url":"nbeet.html#java_decode"},{"doc":"nbeet","title":"java_encode","content":"pub fn java_encode(\n  nbt: Nbt,\n  root_name: String,\n) -&gt; Result(BitArray, Nil)\n\nSynonyms:\nnbeet.java_encode\nnbeet java_encode","url":"nbeet.html#java_encode"},{"doc":"nbeet","title":"java_network_decode","content":"pub fn java_network_decode(\n  bit_array: BitArray,\n  decoder: Decoder(a),\n) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\nnbeet.java_network_decode\nnbeet java_network_decode","url":"nbeet.html#java_network_decode"},{"doc":"nbeet","title":"java_network_encode","content":"pub fn java_network_encode(nbt: Nbt) -&gt; Result(BitArray, Nil)\n\nSynonyms:\nnbeet.java_network_encode\nnbeet java_network_encode","url":"nbeet.html#java_network_encode"},{"doc":"nbeet","title":"list","content":"pub fn list(tag: fn(a) -&gt; Tag, list: List(a)) -&gt; Tag\n\nSynonyms:\nnbeet.list\nnbeet list","url":"nbeet.html#list"},{"doc":"nbeet","title":"long","content":"pub fn long(long: Int) -&gt; Tag\n\nSynonyms:\nnbeet.long\nnbeet long","url":"nbeet.html#long"},{"doc":"nbeet","title":"long_array","content":"pub fn long_array(long_array: List(Int)) -&gt; Tag\n\nSynonyms:\nnbeet.long_array\nnbeet long_array","url":"nbeet.html#long_array"},{"doc":"nbeet","title":"root","content":"pub fn root(root: List(#(String, Tag))) -&gt; Nbt\n\nSynonyms:\nnbeet.root\nnbeet root","url":"nbeet.html#root"},{"doc":"nbeet","title":"short","content":"pub fn short(short: Int) -&gt; Tag\n\nSynonyms:\nnbeet.short\nnbeet short","url":"nbeet.html#short"},{"doc":"nbeet","title":"string","content":"pub fn string(string: String) -&gt; Tag\n\nSynonyms:\nnbeet.string\nnbeet string","url":"nbeet.html#string"},{"doc":"nbeet","title":"nbeet","content":"","url":"nbeet.html"},{"doc":"nbeet/gzip","title":"compress","content":"pub fn compress(data: BitArray) -&gt; BitArray\n\nSynonyms:\nnbeet/gzip.compress\nnbeet/gzip compress","url":"nbeet/gzip.html#compress"},{"doc":"nbeet/gzip","title":"decompress","content":"pub fn decompress(data: BitArray) -&gt; BitArray\n\nSynonyms:\nnbeet/gzip.decompress\nnbeet/gzip decompress","url":"nbeet/gzip.html#decompress"},{"doc":"nbeet/gzip","title":"nbeet/gzip","content":"","url":"nbeet/gzip.html"}]);